@@ -48,6 +48,7 @@ try:
     from gtkgui_helpers import get_action
 except ImportError:
     from gajim.common import app
+    from gajim.common import configpaths
     from gajim.plugins import GajimPlugin
     from gajim.plugins.gui import GajimPluginConfigDialog
     from gajim.htmltextview import HtmlTextView
@@ -93,7 +94,7 @@ def get_local_version(plugin_manifest):
     if not active:
         return
     manifest_path = os.path.join(
-        app.PLUGINS_DIRS[1], short_name, 'manifest.ini')
+        configpaths.get('PLUGINS_USER'), short_name, 'manifest.ini')
     if not os.path.exists(manifest_path):
         return
     conf = configparser.ConfigParser()
@@ -284,14 +285,20 @@ class PluginInstaller(GajimPlugin):
         for _dir in plugin_dirs:
             is_active = False
             plugins = None
-            plugin_dir = os.path.join(app.PLUGINS_DIRS[1], _dir)
+            plugin_dir = os.path.join(configpaths.get('PLUGINS_USER'), _dir)
             plugin = app.plugin_manager.get_plugin_by_path(plugin_dir)
             if plugin:
                 if plugin.active:
                     is_active = True
                     log.info('Deactivate Plugin: %s', plugin)
                     app.plugin_manager.deactivate_plugin(plugin)
-                app.plugin_manager.plugins.remove(plugin)
+
+                if hasattr(app.plugin_manager, 'uninstall_plugin'):
+                    # check if we are running a new version of gajim. Check 
+                    # uninstall because remove_plugin existed before
+                    app.plugin_manager.remove_plugin(plugin)
+                else:
+                    app.plugin_manager.plugins.remove(plugin)
 
                 model = self.installed_plugins_model
                 for row in range(len(model)):
@@ -332,18 +339,27 @@ class PluginInstaller(GajimPlugin):
         dialog.popup()
 
     def available_plugins_treeview_selection_changed(self, treeview_selection):
-        model, iter = treeview_selection.get_selected()
+        model, iter_ = treeview_selection.get_selected()
         self.description_textview.get_buffer().set_text('')
-        self.name_label.set_text(model.get_value(iter, Column.NAME))
-        self.version_label.set_text(model.get_value(iter, Column.VERSION))
-        self.authors_label.set_text(model.get_value(iter, Column.AUTHORS))
+        if not iter_:
+            self.name_label.set_text('')
+            self.version_label.set_text('')
+            self.authors_label.set_text('')
+            self.homepage_linkbutton.set_uri('')
+            self.homepage_linkbutton.set_label('')
+            self.install_button.set_sensitive(False)
+            return
+        self.install_button.set_sensitive(True)
+        self.name_label.set_text(model.get_value(iter_, Column.NAME))
+        self.version_label.set_text(model.get_value(iter_, Column.VERSION))
+        self.authors_label.set_text(model.get_value(iter_, Column.AUTHORS))
         self.homepage_linkbutton.set_uri(
-            model.get_value(iter, Column.HOMEPAGE))
+            model.get_value(iter_, Column.HOMEPAGE))
         self.homepage_linkbutton.set_label(
-            model.get_value(iter, Column.HOMEPAGE))
+            model.get_value(iter_, Column.HOMEPAGE))
         link_label = self.homepage_linkbutton.get_children()[0]
         link_label.set_ellipsize(Pango.EllipsizeMode.END)
-        desc = _(model.get_value(iter, Column.DESCRIPTION))
+        desc = _(model.get_value(iter_, Column.DESCRIPTION))
         if not desc.startswith('<body '):
             desc = ('<body xmlns=\'http://www.w3.org/1999/xhtml\'>'
                     '%s</body>') % desc
@@ -353,12 +369,13 @@ class PluginInstaller(GajimPlugin):
 
     def select_root_iter(self):
         selection = self.available_treeview.get_selection()
-        if selection.count_selected_rows() == 0:
-            root_iter = self.available_plugins_model.get_iter_first()
-            path = self.available_plugins_model.get_path(root_iter)
-            selection.select_iter(root_iter)
+        model, iter_ = selection.get_selected()
+        if not iter_:
+            iter_ = self.available_plugins_model.get_iter_first()
+            selection.select_iter(iter_)
         self.name_label.show()
         self.homepage_linkbutton.show()
+        path = self.available_plugins_model.get_path(iter_)
         self.available_treeview.scroll_to_cell(path)
 
 
@@ -522,7 +539,7 @@ class DownloadAsync(threading.Thread):
         for remote_dir in self.remote_dirs:
             filename = remote_dir + '.zip'
             log.info('Download: %s', filename)
-            base_dir, user_dir = app.PLUGINS_DIRS
+            user_dir = configpaths.get('PLUGINS_USER')
             if not os.path.isdir(user_dir):
                 os.mkdir(user_dir)
             local_dir = os.path.join(user_dir, remote_dir)
